@@ -39,4 +39,11 @@ def call(*args, **kwargs):
             err_result = err_result,
         ))
     # Return the result.
-    return result
\ No newline at end of file
+    return result
+
+
+def call_shell_params(*args, **kwargs):
+    if not "--shell" in args:
+        args += ("--shell",)
+    config_str = call(*args, **kwargs).decode("utf-8")
+    return dict(line.split("=", 1) for line in config_str.splitlines())
\ No newline at end of file
