@@ -27,6 +27,16 @@ SITE_DOMAIN = "{{ app_name }}.herokuapp.com"
 PREPEND_WWW = False
 
 
+# Security settings.
+
+SECURE_PROXY_SSL_HEADER = ("HTTP_X_FORWARDED_PROTO", "https")
+
+ALLOWED_HOSTS = (
+    SITE_DOMAIN,
+    "{{ app_name }}.herokuapp.com",
+)
+
+
 # Database settings.
 
 DATABASES = {
@@ -56,6 +66,8 @@ AWS_HEADERS = {
     "Cache-Control": "public, max-age=86400",
 }
 
+AWS_S3_FILE_OVERWRITE = False
+
 AWS_QUERYSTRING_AUTH = False
 
 AWS_S3_SECURE_URLS = False
